@@ -11,7 +11,7 @@ use PiFlash::Inspector;
 use PiFlash::MediaWriter;
 
 package PiFlash;
-$PiFlash::VERSION = '0.4.0';
+$PiFlash::VERSION = '0.4.1';
 use autodie; # report errors instead of silently continuing ("die" actions are used as exceptions - caught & reported)
 use Getopt::Long qw(GetOptionsFromArray); # included with perl
 use File::Basename; # included with perl
@@ -35,6 +35,22 @@ sub state_categories {
 	);
 };
 
+# return list of command-line options in Getopt::Long-compatible format
+sub cli_def
+{
+	return (
+		"config:s",		# configuration file
+		"help",			# display help/usage and exit
+		"logging",		# command logging (similar to verbose mode without printing anything)
+		"plugin:s",		# list of user-enabled plugins (also enabled from config file)
+		"resize",		# resize root filesystem after writing to SD card
+		"sdsearch",		# display list of SD card devices and exit
+		"test:s%",		# set test flags (used by unit tests only)
+		"verbose",		# log and print lots of actions for troubleshooting
+		"version",		# print version number and exit
+	);
+}
+
 # print program usage message
 sub usage
 {
@@ -48,7 +64,7 @@ sub usage
 	push @msg, "usage: ".basename($0)." [--verbose | --logging] [--resize] [--config conf-file] input-file output-device";
 	push @msg, "       ".basename($0)." [--verbose | --logging] [--config conf-file] --SDsearch";
 	push @msg, "       ".basename($0)." --version";
-	PiFlash::State->error(join("\n", @msg)."\n");
+	die join("\n", @msg)."\n";
 }
 
 # print numbers with readable suffixes for megabytes, gigabytes, terabytes, etc
@@ -79,16 +95,7 @@ sub process_cli
 				push @warn, $_[0];
 			}
 		};
-		my $getopt_result = eval { GetOptionsFromArray ($cmdline, PiFlash::State::cli_opt(),
-			"config:s",
-			"logging",
-			"plugin:s",
-			"resize",
-			"sdsearch",
-			"test:s%",
-			"verbose",
-			"version",
-			)
+		my $getopt_result = eval { GetOptionsFromArray ($cmdline, PiFlash::State::cli_opt(), PiFlash::cli_def())
 		};
 		if ($@) {
 			# in case of failure, add state info if verbose or logging mode is set
@@ -105,7 +112,7 @@ sub process_cli
 	# check for errors such as insufficient parameters or missing files
 	my @errors;
 	my $cli_query_mode = 0;
-	foreach my $opt ( qw(sdsearch version) ) {
+	foreach my $opt ( qw(help sdsearch version) ) {
 		if (PiFlash::State::has_cli_opt($opt)) {
 			$cli_query_mode = 1;
 			last;
@@ -149,6 +156,11 @@ sub piflash
 	# process command line
 	process_cli();
 
+	# if --help option was selected, print usage info and exit
+	if (PiFlash::State::has_cli_opt("help")) {
+		usage();
+	}
+
 	# if --version option was selected, print the version number and exit
 	if (PiFlash::State::has_cli_opt("version")) {
 		say $PiFlash::VERSION;
@@ -273,7 +285,7 @@ PiFlash - Raspberry Pi SD-flashing script with safety checks to avoid erasing th
 
 =head1 VERSION
 
-version 0.4.0
+version 0.4.1
 
 =head1 SYNOPSIS
 
@@ -281,16 +293,19 @@ version 0.4.0
 
 =head1 DESCRIPTION
 
-See the L<piflash> program for details on installation and command-line usage.
+See the L<piflash> program for details on installation and running the program at the command line.
 
-This is the top-level command-line processing level of the L<piflash> script to flash an SD card for a Raspberry Pi
-single-board computer. The main function serves as an exception catching wrapper which calls the piflash function
+The PiFlash module is the top-level command-line processing level of the L<piflash> script
+to flash an SD card for a Raspberry Pi single-board computer.
+The main function serves as an exception catching wrapper which calls the piflash function
 to process the command line.
 
 =head1 SEE ALSO
 
 L<PiFlash::Command>, L<PiFlash::Inspector>, L<PiFlash::MediaWriter>, L<PiFlash::State>
 
+PiFlash online resources L<https://github.com/ikluft/piflash/blob/master/doc/resources.md>
+
 L<https://metacpan.org/release/PiFlash> - main PiFlash release page on MetaCPAN
 
 L<https://github.com/ikluft/piflash> - PiFlash repository on GitHub
